@@ -1,8 +1,21 @@
 # Classes / functions imported with mavenn
 from mavenn.src.model import Model
-from mavenn.src.UI import GlobalEpistasisModel
-from mavenn.src.UI import NoiseAgnosticModel
+
 from mavenn.src.error_handling import handle_errors, check
+from mavenn.src.utils import get_example_dataset
+from mavenn.tests.functional_tests_mavenn import run_tests
+
+from mavenn.src.utils import load
+from mavenn.src.utils import estimate_instrinsic_information
+
+from mavenn.src.utils import SkewedTNoiseModel
+from mavenn.src.utils import GaussianNoiseModel
+from mavenn.src.utils import CauchyNoiseModel
+
+from mavenn.src import entropy_estimators as ee
+
+from mavenn.src.utils import heatmap
+from mavenn.src.utils import get_1pt_variants
 
 # imports required for helper functions in demos
 import pandas as pd
@@ -25,7 +38,7 @@ def demo(name='GEmpsa'):
     -----------
 
     name: (str)
-        Must be one of {'GEmpsa, GEGB1, GEmpsaPairwise, NAsortseq'}.
+        Must be one of {'GEmpsa, GEGB1, GEmpsaTrain, NAsortseq'}.
 
     returns
     -------
